package internal

import (
	"crypto/aes"
	"encoding/base64"
	"fmt"
	"gitee.com/chengdu_blue_brothers/openapi-go-sdk-v2/sdk/requests"
	"strings"
)

func getScheme(url string) string {
	if strings.HasPrefix(url, "https://") {
		return requests.HTTPS
	}
	return requests.HTTP
}

func getDomain(url, scheme string) (string, error) {
	if strings.HasPrefix(url, fmt.Sprintf("%s://", strings.ToLower(scheme))) {
		parts := strings.Split(url, "//")
		if len(parts) >= 2 {
			return parts[1], nil
		}
	}
	return "", fmt.Errorf("invalid url")
}

func decryptAES(encryptedData string, secretKey string) (string, error) {
	// 第一步：对加密的卡密做base64 decode
	encryptedBytes, err := base64.StdEncoding.DecodeString(encryptedData)
	if err != nil {
		return "", err
	}
	// 第二步：使用aes-256-ecb解密
	cipher, _ := aes.NewCipher([]byte(secretKey))
	decrypted := make([]byte, len(encryptedBytes))
	size := 16
	for bs, be := 0, size; bs < len(encryptedBytes); bs, be = bs+size, be+size {
		cipher.Decrypt(decrypted[bs:be], encryptedBytes[bs:be])
	}
	paddingSize := int(decrypted[len(decrypted)-1])
	return string(decrypted[0 : len(decrypted)-paddingSize]), nil
}
